==> myfaces-tobago-3.0.6-source-release.zip: tobago-3.0.6/tobago-example/tobago-example-demo/src/main/java/org/apache/myfaces/tobago/example/demo/RoleController.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

package org.apache.myfaces.tobago.example.demo;

import javax.annotation.security.RolesAllowed;
import javax.enterprise.context.SessionScoped;
import javax.inject.Named;
import java.io.Serializable;

@SessionScoped
@Named
public class RoleController implements Serializable {

  private String text;
  private static final String OUTCOME_ADMIN = "admin";

  public String getText() {
    return text;
  }

  public void setText(String text) {
    this.text = text;
  }

  @RolesAllowed({"demo-admin", "demo-guest"})
  public boolean guestBox() {
    return true;
  }

  @RolesAllowed({"demo-admin"})
  public boolean adminBox() {
    return true;
  }

  @RolesAllowed({"demo-admin"})
  public String admin() {
    return OUTCOME_ADMIN;
  }
}

==> myfaces-tobago-4.4.1-source-release.zip: tobago-4.4.1/tobago-example/tobago-example-demo/src/main/java/org/apache/myfaces/tobago/example/demo/RoleController.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

package org.apache.myfaces.tobago.example.demo;

import javax.annotation.security.RolesAllowed;
import javax.enterprise.context.SessionScoped;
import javax.inject.Named;
import java.io.Serializable;

@SessionScoped
@Named
public class RoleController implements Serializable {

  private String text;
  private static final String OUTCOME_ADMIN = "admin";

  public String getText() {
    return text;
  }

  public void setText(final String text) {
    this.text = text;
  }

  @RolesAllowed({"demo-admin", "demo-guest"})
  public boolean guestBox() {
    return true;
  }

  @RolesAllowed({"demo-admin"})
  public boolean adminBox() {
    return true;
  }

  @RolesAllowed({"demo-admin"})
  public String admin() {
    return OUTCOME_ADMIN;
  }
}
